<?php

/**
 * Gulliver Base Class.
 *
 * $Horde: gulliver/lib/Gulliver.php,v 1.15 2006/03/07 18:17:34 slusarz Exp $
 *
 * Copyright 2004-2006 Duck <duck@obala.net>
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author  Duck <duck@obala.net>
 * @package Gulliver
 */
class Gulliver {

    /**
    * Format date
    */
    function formatDate($time)
    {
        if (intval($time)<1000000000) {
            $time = strtotime($time);
        }
        return strftime($GLOBALS['prefs']->getValue('date_format'), $time);
    }

    /**
    * Format price
    */
    function formatPrice($price)
    {
        static $info;

        if (is_null($info)) {
            $currencies = new Horde_CurrenciesMapper();
            $default = $currencies->getDefault();
            $info = $currencies->getOne($default);
        }

        return Horde_Currencies::formatPrice($price, $info);
    }

    /**
     * Build clients lists
     *
     * @return  array   client list
     */
    function listClients()
    {
        $args = array('addresses' => array(''),
                      'fields' => array('name'));
        $result = $GLOBALS['registry']->call('clients/searchClients', $args);
        if (is_a($result, 'PEAR_Error')) {
            return $result;
        }
        $clients = array();
        if (!empty($result)) {
            $result = current($result);
            foreach ($result as $client) {
                $clients[$client['id']] = $client;
            }
        }

        return $clients;
    }

    /**
     * Build clients lists
     *
     * @param string $client Client ID
     *
     * @return  array   client attributes list
     */
    function clientData($client)
    {
        static $clientmap;

        if (is_null($clientmap)) {
            require GULLIVER_BASE . '/config/clientmap.php';
        }

        $clients = Gulliver::listClients();
        $client = $clients[$client];

        foreach ($clientmap as $orig => $map) {
            if (is_array($map)) {
                $client[$orig] = '';
                foreach ($map as $part) {
                    $client[$orig] .= isset($client[$part]) ? $client[$part] : $part;
                }
            } elseif(isset($client[$map])) {
                $client[$orig] = $client[$map];
            }
        }

        return $client;
    }

    /**
    * Get avaiable client
    *
    * @return  array   attribute list      
    */
    function clientsFields()
    {
        static $fields;
    
        if (!is_null($fields)) {
            return $fields;
        }

        $fields = array();
        $source = $GLOBALS['registry']->call('clients/getClientSource');
        foreach ($GLOBALS['registry']->call('clients/fields', $source) as $attribute) {
            $fields[$attribute['name']] = $attribute['label'];
        }

        return $fields;
    }

    /**
     * Build veichles lists
     *
     * @return  array   client list
     */
    public function getVehicles()
    {
        static $vehicles;

        if (is_null($vehicles)) {
            include_once GULLIVER_BASE . '/lib/RDO/Vehicle.php';
            $mapper = new Gulliver_VehicleMapper();
            $vehicles = $mapper->getAll();
        }

        return $vehicles;
    }

    /**
     * Build workers lists
     *
     * @return  array   client list
     */
    public function getWorkers()
    {
        static $workers;

        if (is_null($workers)) {
            include_once GULLIVER_BASE . '/lib/RDO/Worker.php';
            $mapper = new Gulliver_WorkerMapper();
            $workers = $mapper->getAll();
        }

        return $workers;
    }

    /**
     * Get userID of a worker
     *
     * @return  array   client list
     */
    public function getUserWorkerID()
    {
        $mapper = new Gulliver_WorkerMapper();
        $user = $mapper->find(Horde_RDO::FIND_FIRST, array('horde_uid' => Auth::getAuth()));
        return $user->id;
    }

    /**
     * Get cities
     *
     * @return  array   client list
     */
    public function getCities()
    {
        static $cities;

        if (is_null($cities)) {
            include_once GULLIVER_BASE . '/lib/RDO/City.php';
            $mapper = new Gulliver_CitiesMapper();
            $cities = $mapper->getAll();
        }

        return $cities;
    }

    /**
     * Get countries
     *
     * @return  array   client list
     */
    function getCountries()
    {
        static $countries;

        if (is_null($countries)) {
            include_once GULLIVER_BASE . '/lib/RDO/Country.php';
            $mapper = new Gulliver_CountryMapper();
            $countries = $mapper->getAll();
        }

        return $countries;
    }

    /**
     * Get manufacturers
     *
     * @return  array   client list
     */
    public function getManufacturers()
    {
        static $manufacturers;

        if (is_null($manufacturers)) {
            include_once GULLIVER_BASE . '/lib/RDO/Manufacturer.php';
            $mapper = new Gulliver_ManufacturerMapper();
            $manufacturers = $mapper->getAll();
        }

        return $manufacturers;
    }

    /**
     * Get currencies
     *
     * @return  array   client list
     */
    function getCurrencies()
    {
        static $currencies;

        if (is_null($currencies)) {
            $mapper = new Horde_CurrenciesMapper();
            $data = $mapper->getAll();
            $currencies = array();
            foreach ($data as $value) {
                $currencies[$value['currency_symbol']] = $value['currency_symbol'];
            }
        }

        return $currencies;
    }

    /**
    * Return HTML_AJAX path
    */
    function ajaxPath()
    {
        $url = Horde::applicationUrl('trips/ajaxcontroller.php');
        return Util::addParameter($url, array('client' => 'html_ajax_lite', 'stub' => 'gulliver_ajax'), false, false);
    }

    /**
     * Build Gullivers's list of menu items.
     */
    function getMenu($returnType = 'object')
    {
        global $conf, $registry, $browser, $print_link;

        require_once 'Horde/Menu.php';

        $menu = &new Menu(HORDE_MENU_MASK_ALL);
        $menu->add(Horde::applicationUrl('trips/list.php'), _("List"), 'user.png', $registry->getImageDir('horde'));

        if (Auth::isAdmin('gulliver')) {
            $menu->add(Horde::applicationUrl('admin/cities.php'), _("Admin"), 'administration.png', $registry->getImageDir('horde'));
        }

        if ($returnType == 'object') {
            return $menu;
        } else {
            return $menu->render();
        }
    }

}
